<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>AboutWindow</name>
    <message>
        <location filename="aboutwindow.ui" line="14"/>
        <source>QtBatteryWidget - About</source>
        <translation type="unfinished">QtBatteryWidget - About</translation>
    </message>
    <message>
        <location filename="aboutwindow.cpp" line="33"/>
        <source>Back</source>
        <translation type="unfinished">Indietro</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished">MainWindow</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="33"/>
        <source>Voltage:</source>
        <translation type="unfinished">Voltaggio:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="46"/>
        <location filename="mainwindow.ui" line="62"/>
        <location filename="mainwindow.ui" line="92"/>
        <location filename="mainwindow.ui" line="115"/>
        <source>-</source>
        <translation type="unfinished">-</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="72"/>
        <source>Charge:</source>
        <translation type="unfinished">Carica:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="79"/>
        <source>Time left:</source>
        <translation type="unfinished">Tempo residuo:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="102"/>
        <source>Temp.:</source>
        <translation type="unfinished">Temp.:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="162"/>
        <source>0.0 %</source>
        <translation type="unfinished">0.0 %</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="473"/>
        <source>%1% Charging</source>
        <translation type="unfinished">%1% In carica</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="commonstatic.cpp" line="39"/>
        <source>Confirm</source>
        <translation type="unfinished">Conferma</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="14"/>
        <source>Settings</source>
        <translation type="unfinished">Impostazioni</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="59"/>
        <source>Data source:</source>
        <translation type="unfinished">Sorgente dei dati:</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="69"/>
        <source>Percentage style:</source>
        <translation type="unfinished">Stile percentuale:</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="79"/>
        <source>Percentage Size:</source>
        <translation type="unfinished">Dimensione percentuale:</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="99"/>
        <source>Time left:</source>
        <translation type="unfinished">Tempo residuo:</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="109"/>
        <source>Show labels</source>
        <translation type="unfinished">Visualizza etichette</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="116"/>
        <source>Show charge</source>
        <translation type="unfinished">Visualizza carica</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="123"/>
        <source>Show voltage</source>
        <translation type="unfinished">Visualizza voltaggio</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="130"/>
        <source>Show time left</source>
        <translation type="unfinished">Visualizza tempo residuo</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="137"/>
        <source>Show temperature</source>
        <oldsource>Show Temp.</oldsource>
        <translation type="unfinished">Visualizza temperatura</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="144"/>
        <source>Opacity:</source>
        <translation type="unfinished">Trasparenza:</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="161"/>
        <source>About</source>
        <translation type="unfinished">About</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="185"/>
        <source>Save</source>
        <translation type="unfinished">Salva</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="34"/>
        <source>Default</source>
        <translation type="unfinished">Default</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="36"/>
        <source>bq27200</source>
        <translation type="unfinished">bq27200</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="37"/>
        <source>dr_frost_dk</source>
        <translation type="unfinished">dr_frost_dk</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="39"/>
        <source>Graphical</source>
        <translation type="unfinished">Grafico</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="40"/>
        <source>Standard</source>
        <translation type="unfinished">Standard</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="41"/>
        <source>Textual</source>
        <translation type="unfinished">Testuale</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="59"/>
        <source>from power consumption</source>
        <translation type="unfinished">basato sul consumo</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="60"/>
        <source>from percentage change</source>
        <translation type="unfinished">basato sulla variazione percentuale</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="95"/>
        <source>Opacity: %1</source>
        <translation type="unfinished">Trasparenza: %1</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="100"/>
        <source>Percentage Size: %1%</source>
        <translation type="unfinished">Dimensione percentuale: %1%</translation>
    </message>
</context>
</TS>
